# Generated by Django 3.0 on 2022-09-02 10:00

from django.db import migrations
from django.contrib.postgres.operations import TrigramExtension


class Migration(migrations.Migration):

    dependencies = [
        ('camomilla', '0010_auto_20220802_1406'),
    ]

    operations = [
        TrigramExtension()
    ]
